<?php


class User extends CI_Controller{
    function __construct()
    {
        parent::__construct();

        if (!$this->ion_auth->logged_in())
	    {
	      redirect('auth/login');
	    }else if (!$this->ion_auth->is_admin())
		{
			redirect('/', 'refresh');
		}
        $this->load->model('User_model');
    }

    /*
     * Listing of users
     */
    function index()
    {
        $data['users'] = $this->User_model->get_all_users();

        $data['_view'] = 'user/index';
        $this->load->view('layouts/main',$data);
    }

    /*
     * Adding a new user
     */
    function add()
    {
    	$this->load->library('form_validation');

        $this->form_validation->set_rules('first_name', 'Nombre', 'required');
        $this->form_validation->set_rules('last_name', 'Apellido', 'required');
        $this->form_validation->set_rules('username', 'Usuario', 'required');
        $this->form_validation->set_rules('email', 'Email', 'required|valid_email|is_unique[users.email]');
    	$this->form_validation->set_rules('password', 'Password', 'required');
		$this->form_validation->set_rules('password_confirm', 'Conformar Password', 'required|matches[password]');

        if($this->form_validation->run() === TRUE)
         {
            $max_id = $this->User_model->get_max_user_id();

            if ($max_id > 1){
                $id = $max_id + 1;
	            $hash = password_hash($this->input->post('password'), PASSWORD_BCRYPT, array("cost" => 10));

	            $params = array(
                    'id'   => $id,
	            	'first_name' => $this->input->post('first_name'),
					'last_name' => $this->input->post('last_name'),
					'username' => strtolower($this->input->post('username')),
					'email' => strtolower($this->input->post('email')),
					'password' => $hash,
					'active' => $this->input->post('active'),
					'company' => $this->input->post('company'),
					'phone' => $this->input->post('phone'),
	            );

	            $user_id = $this->User_model->add_user($params);

            }else {
              //Mostrar Mensaje de Error
            }
            redirect('user/index');
        }
        else
        {
            $data['_view'] = 'user/add';
            $this->load->view('layouts/main',$data);
        }
    }

    /*
     * Editing a user
     */
    function edit($id)
    {
        // check if the user exists before trying to edit it
        $data['user'] = $this->User_model->get_user($id);

        if(isset($data['user']['id']))
        {
            if(isset($_POST) && count($_POST) > 0)
            {
                $params = array(
					'username' => $this->input->post('username'),
					'email' => $this->input->post('email'),
					'active' => $this->input->post('active'),
					'first_name' => $this->input->post('first_name'),
					'last_name' => $this->input->post('last_name'),
					'company' => $this->input->post('company'),
					'phone' => $this->input->post('phone'),
                );

                $this->User_model->update_user($id,$params);
                redirect('user/index');
            }
            else
            {
                $data['_view'] = 'user/edit';
                $this->load->view('layouts/main',$data);
            }
        }
        else
            show_error('The user you are trying to edit does not exist.');
    }

     /*
     * Editing a user
     */
    function group($id)
    {
        // check if the user exists before trying to edit it
        $data['user'] = $this->User_model->get_user($id);
        $data['groups'] = $this->User_model->get_all_groups();
		$data['currentGroups'] = $this->User_model->get_users_groups($id);

        if(isset($data['user']['id']))
        {
            if(isset($_POST) && count($_POST) > 0)
            {

            	$groupData = $this->input->post('groups');
				if (isset($groupData) && !empty($groupData))
				{
					 $this->User_model->add_user_group($groupData, $id);

				}

                redirect('user/index');
            }
            else
            {
                $data['_view'] = 'user/group';
                $this->load->view('layouts/main',$data);
            }
        }
        else
            show_error('The user you are trying to edit does not exist.');
    }


    /*
     * Deleting user
     */
    function remove($id)
    {
        $user = $this->User_model->get_user($id);

        // check if the user exists before trying to delete it
        if(isset($user['id']))
        {
            $this->User_model->delete_user($id);
            redirect('user/index');
        }
        else
            show_error('The user you are trying to delete does not exist.');
    }

}
